==> apache-artemis-2.22.0-source-release.tar.gz: apache-artemis-2.22.0/tests/integration-tests/src/test/java/org/apache/activemq/artemis/tests/integration/openwire/amq/JmsDurableQueueWildcardSendReceiveTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.tests.integration.openwire.amq;

import org.apache.activemq.artemis.core.config.Configuration;
import org.apache.activemq.artemis.core.settings.impl.AddressSettings;

import javax.jms.DeliveryMode;

/**
 * adapted from: org.apache.activemq.JmsDurableQueueWildcardSendReceiveTest
 */
public class JmsDurableQueueWildcardSendReceiveTest extends JmsTopicSendReceiveTest {

   @Override
   public void setUp() throws Exception {
      topic = false;
      deliveryMode = DeliveryMode.PERSISTENT;
      super.setUp();
   }

   @Override
   protected String getConsumerSubject() {
      return "FOO.>";
   }

   @Override
   protected String getProducerSubject() {
      return "FOO.BAR.HUMBUG";
   }

   @Override
   protected void extraServerConfig(Configuration serverConfig) {
      AddressSettings settings = serverConfig.getAddressesSettings().get("#");
      if (settings != null) {
         settings.setAutoCreateQueues(true);
      }
   }

}

==> apache-artemis-2.33.0-source-release.tar.gz: apache-artemis-2.33.0/tests/integration-tests/src/test/java/org/apache/activemq/artemis/tests/integration/openwire/amq/JmsDurableQueueWildcardSendReceiveTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.tests.integration.openwire.amq;

import org.apache.activemq.artemis.core.config.Configuration;
import org.apache.activemq.artemis.core.settings.impl.AddressSettings;

import javax.jms.DeliveryMode;

/**
 * adapted from: org.apache.activemq.JmsDurableQueueWildcardSendReceiveTest
 */
public class JmsDurableQueueWildcardSendReceiveTest extends JmsTopicSendReceiveTest {

   @Override
   public void setUp() throws Exception {
      topic = false;
      deliveryMode = DeliveryMode.PERSISTENT;
      super.setUp();
   }

   @Override
   protected String getConsumerSubject() {
      return "FOO.>";
   }

   @Override
   protected String getProducerSubject() {
      return "FOO.BAR.HUMBUG";
   }

   @Override
   protected void extraServerConfig(Configuration serverConfig) {
      AddressSettings settings = serverConfig.getAddressSettings().get("#");
      if (settings != null) {
         settings.setAutoCreateQueues(true);
      }
   }

}
